"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const content_checker_1 = require("@ewizardjs/content-checker");
const commander_1 = require("commander");
const action_1 = require("../Api/versionControl/action");
const Logger_1 = require("../modules/Logger");
const I18n_1 = require("../modules/I18n");
const ensureAuth_1 = require("./utils/ensureAuth");
const mergeUtils_1 = require("../Api/versionControl/MergeTool/mergeUtils");
const program = new commander_1.Command();
program
    .name('wiz pull')
    .description('wiz pull - Applies the upstream changes to your local project')
    .addOption(new commander_1.Option('--accept <type>', I18n_1.default.info('PULL_ACCEPT_OPTION')).choices(mergeUtils_1.AutoResolve))
    .configureHelp({
    optionDescription: (option) => option.description,
})
    .parse(process.argv);
ensureAuth_1.default()
    .then(() => pull(process.cwd(), program.opts()))
    .catch((err) => Logger_1.default.error(err.message));
function pull(baseDir, commandOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        yield content_checker_1.validateEwizardContent(baseDir);
        yield content_checker_1.validateInstalledDependencies(baseDir);
        return action_1.createVCSAction(baseDir, { actionType: 'pull' }, commandOptions);
    });
}
//# sourceMappingURL=wiz-pull.js.map